/* Parallel Resistor Calculator version 1.0
 *
 * Calculates the value of the resistance from two parallel resistors
 *
 * written by Hein Venter
 * Dec 1998
 */

#pragma pack(2)
#include <Common.h>
#include <System/SysAll.h>
#include <UI/UIAll.h>

#include "parres.h"

static int StartApplication(void);
static void EventLoop(void);
static void StopApplication(void);
static Boolean form1(EventPtr event);
static void Calculate(void);

FieldPtr	fieldptr_res1;
FieldPtr	fieldptr_res2;
FieldPtr	fieldptr_rslt;

DWord  PilotMain (Word cmd, Ptr cmdPBP, Word launchFlags)
{
  int error;

  if (cmd == sysAppLaunchCmdNormalLaunch)
 {

    error = StartApplication();	// Application start code
    if (error) return error;

    EventLoop();	// Event loop

    StopApplication ();	// Application stop code
  }
  return 0;
}

static int StartApplication(void)
{
  int error;

  FrmGotoForm(formID_form);
}


static void EventLoop(void)
{
  short err;
  int formID;
  FormPtr form;
  EventType event;

  do
  {

    EvtGetEvent(&event, -1);

    if (SysHandleEvent(&event)) continue;
    if (MenuHandleEvent((void *)0, &event, &err)) continue;

    if (event.eType == frmLoadEvent)
    {
      formID = event.data.frmLoad.formID;
      form = FrmInitForm(formID);
      FrmSetActiveForm(form);
      switch (formID) 
      {
      case formID_form:
        FrmSetEventHandler(form, (FormEventHandlerPtr) form1);
        break;
      }
    } 
    FrmDispatchEvent(&event);
  } while(event.eType != appStopEvent);
}

static void StopApplication(void)
{
	while (0);
}

static Boolean form1(EventPtr event)
{
  FormPtr   form;
  int       handled = 0;
  EventType newEvent;

  switch (event->eType) 
  {
  case frmOpenEvent:
    form = FrmGetActiveForm();
    fieldptr_res1 = FrmGetObjectPtr(form, FrmGetObjectIndex(form, fieldID_res1));
    fieldptr_res2 = FrmGetObjectPtr(form, FrmGetObjectIndex(form, fieldID_res2));
    fieldptr_rslt = FrmGetObjectPtr(form, FrmGetObjectIndex(form, fieldID_rslt));
    FrmDrawForm(form);
	FrmSetFocus(form, FrmGetObjectIndex(form, fieldID_res1));
    handled = 1;
    break;
    
  case ctlSelectEvent:  // A control button was pressed and released.
    if (event->data.ctlEnter.controlID== buttonID_done)
    {
        MemSet(&newEvent, sizeof(EventType), 0);
        newEvent.eType = appStopEvent;
		EvtAddEventToQueue(&newEvent);
		handled = 1;
    }
    if (event->data.ctlEnter.controlID== buttonID_calc)
	{
		Calculate();
		handled = 1;
	}
	break;

  case menuEvent:
    switch (event->data.menu.itemID)
    {
    case menuitemID_calc:
      Calculate();
      break;
    case menuitemID_about:
      FrmAlert(alertID_about);
      break;
    case menuitemID_done:
      MemSet(&newEvent, sizeof(EventType), 0);
      newEvent.eType = appStopEvent;
	  EvtAddEventToQueue(&newEvent);
	  break;
    }
    handled = 1;
    break;

  case nilEvent:
    handled = 1;
    break;
  }
  return handled;
}

static void Calculate(void)
{
  int  res1length, res2length;
  long  r1, r2;
  float r3;
  char rslt[15];
  CharPtr  res1pointer, res2pointer;

  res1pointer = FldGetTextPtr(fieldptr_res1);
  res2pointer = FldGetTextPtr(fieldptr_res2);
  res1length = FldGetTextLength(fieldptr_res1);
  res2length = FldGetTextLength(fieldptr_res2);
  if ((res1length) && (res2length))
  {
    r1=StrAToI(res1pointer);
	r2=StrAToI(res2pointer);
	if ((r1>0) && (r2>0))
	{
	  r3=((float)r1*(float)r2)/((float)r1+(float)r2);
	  StrIToA(rslt, (long)r3);
	  FldSetTextPtr(fieldptr_rslt, rslt);
      FldRecalculateField(fieldptr_rslt, true);
      FrmDrawForm(FrmGetActiveForm());
	}
	else
	{
	  FrmAlert(alertID_errornullstring);
	}
  }
  else
  {
    FrmAlert(alertID_errornullstring);
  }
}

